@@ -100,7 +100,7 @@ def update_body(app, pagename, templatename, context, doctree):
     # This decouples the theme CSS (which is versioned independently) from readthedocs.org
     if theme_css.endswith('sphinx_rtd_theme.css'):
         try:
-            import sphinx_rtd_theme
+            import sphinx_rtd_theme  # noqa
             inject_css = LooseVersion(sphinx_rtd_theme.__version__) < LooseVersion('0.4.0')
         except ImportError:
             pass
@@ -111,6 +111,23 @@ def update_body(app, pagename, templatename, context, doctree):
         else:
             app.add_css_file(theme_css)
 
+    # Add the Read the Docs embed
+    # This *must* come after Sphinx has loaded jQuery as it relies on it.
+    # Unless this script is modified to not rely on jQuery (a good goal),
+    # it can't just be put into the extrahead
+    # in case a theme outputs scripts at the end of the body
+    js_file = '{}javascript/readthedocs-doc-embed.js'.format(STATIC_URL)
+    if all((
+        app.builder.name in ONLINE_BUILDERS,
+        hasattr(app.builder, 'script_files'),
+        js_file not in app.builder.script_files,
+    )):
+        if sphinx.version_info < (1, 8):
+            app.builder.script_files.append(js_file)
+        else:
+            kwargs = {'async': 'async'}     # Workaround reserved word in Py3.7
+            app.add_js_file(js_file, **kwargs)
+
     # This is monkey patched on the signal because we can't know what the user
     # has done with their `app.builder.templates` before now.
 
@@ -145,9 +162,7 @@ def update_body(app, pagename, templatename, context, doctree):
                 'build_date': datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%SZ'),
                 'global_analytics_code': ctx.get('global_analytics_code'),
                 'user_analytics_code': ctx.get('user_analytics_code'),
-                'subprojects': {
-                    slug: url for slug, url in ctx.get('subprojects', [])
-                },
+                'subprojects': dict(ctx.get('subprojects', [])),
                 'features': {
                     'docsearch_disabled': ctx.get('docsearch_disabled', False),
                 },
@@ -157,7 +172,6 @@ def update_body(app, pagename, templatename, context, doctree):
             if ctx.get('proxied_api_host'):
                 ctx['rtd_data']['proxied_api_host'] = ctx['proxied_api_host']
             ctx['rtd_css_url'] = '{}css/readthedocs-doc-embed.css'.format(STATIC_URL)
-            ctx['rtd_js_url'] = '{}javascript/readthedocs-doc-embed.js'.format(STATIC_URL)
             ctx['rtd_analytics_url'] = '{}javascript/readthedocs-analytics.js'.format(STATIC_URL)
             source = os.path.join(
                 os.path.abspath(os.path.dirname(__file__)),
@@ -383,4 +397,6 @@ def setup(app):
     app.add_builder(ReadtheDocsDirectoryHTMLBuilder)
     app.add_builder(ReadtheDocsSingleFileHTMLBuilder)
 
-    return {}
+    return {
+        'parallel_read_safe': True,
+    }
